==> xmake_3.0.4+ds.orig.tar.xz: xmake-3.0.4/core/src/xmake/thread/event_init.c <==
/*!A cross-platform build utility based on Lua
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Copyright (C) 2015-present, Xmake Open Source Community.
 *
 * @author      ruki
 * @file        event_init.c
 *
 */

/* //////////////////////////////////////////////////////////////////////////////////////
 * trace
 */
#define TB_TRACE_MODULE_NAME                "thread_event"
#define TB_TRACE_MODULE_DEBUG               (0)

/* //////////////////////////////////////////////////////////////////////////////////////
 * includes
 */
#include "prefix.h"

/* //////////////////////////////////////////////////////////////////////////////////////
 * implementation
 */
tb_int_t xm_thread_event_init(lua_State* lua)
{
    tb_assert_and_check_return_val(lua, 0);

    tb_bool_t ok = tb_false;
    xm_thread_event_t* thread_event = tb_null;
    do
    {
        thread_event = tb_malloc0_type(xm_thread_event_t);
        tb_assert_and_check_break(thread_event);

        thread_event->refn = 1;
        thread_event->handle = tb_event_init();
        tb_assert_and_check_break(thread_event->handle);

        xm_lua_pushpointer(lua, (tb_pointer_t)thread_event);
        ok = tb_true;

    } while (0);

    if (!ok)
    {
        if (thread_event)
        {
            if (thread_event->handle)
            {
                tb_event_exit(thread_event->handle);
                thread_event->handle = tb_null;
            }
            tb_free(thread_event);
        }
        lua_pushnil(lua);
    }
    return 1;
}

==> xmake_3.0.7+ds.orig.tar.xz: xmake-3.0.7/core/src/xmake/thread/event_init.c <==
/*!A cross-platform build utility based on Lua
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Copyright (C) 2015-present, Xmake Open Source Community.
 *
 * @author      ruki
 * @file        event_init.c
 *
 */

/* //////////////////////////////////////////////////////////////////////////////////////
 * trace
 */
#define TB_TRACE_MODULE_NAME "thread_event"
#define TB_TRACE_MODULE_DEBUG (0)

/* //////////////////////////////////////////////////////////////////////////////////////
 * includes
 */
#include "prefix.h"

/* //////////////////////////////////////////////////////////////////////////////////////
 * implementation
 */
tb_int_t xm_thread_event_init(lua_State *lua) {
    tb_assert_and_check_return_val(lua, 0);

    tb_bool_t ok = tb_false;
    xm_thread_event_t *thread_event = tb_null;
    do {
        thread_event = tb_malloc0_type(xm_thread_event_t);
        tb_assert_and_check_break(thread_event);

        thread_event->refn   = 1;
        thread_event->handle = tb_event_init();
        tb_assert_and_check_break(thread_event->handle);

        xm_lua_pushpointer(lua, (tb_pointer_t)thread_event);
        ok = tb_true;

    } while (0);

    if (!ok) {
        if (thread_event) {
            if (thread_event->handle) {
                tb_event_exit(thread_event->handle);
                thread_event->handle = tb_null;
            }
            tb_free(thread_event);
        }
        lua_pushnil(lua);
    }
    return 1;
}
